#!/bin/bash

recorderHelp()
{
	cat '../docs/record.txt'
}

syntaxCheck_1() {
    if [ $# -ne 6 ] && [ $# -ne 8 ] && [ $# -ne 10 ] 
    then
        echo
        echo 'bad number of arguments'
        echo
        recorderHelp $@
        exit 1
    fi
}

syntaxCheck_2() {

    if [ "$3" != 'at' ]
    then
        echo
        echo 'bad syntax'
        echo
        recorderHelp $@
        exit 1	
    fi
    if [ "$5" != 'until' ] && [ "$5" != 'for' ] 
    then
        echo
        echo 'bad syntax'
        echo
        recorderHelp $@
        exit 1	
    fi
}

setRecordingName() {
    local name='pvr'
    
    if [ $# -eq 8 ] && [ "$7" = "name" ]
    then
        name="$8"
    fi
    if [ $# -eq 10 ] && [ "$9" = "name" ]
    then
        name="$10"
    fi

    echo $name
}

#
# $1 - name
# $2 - a date string recognised by `date` command
#
#
appendDate() {
    echo "${1}-"`date +%Y-%m-%d-%H:%M--%a --date="$2"`'.ts'
}

setMargins() {
    if [ 1 -eq $have_custom_margins ]
    then
        pre_margin=`echo $margins | grep -o ^[^\-]*`
        post_margin=`echo $margins | grep -o [^\-]*$`	
    fi
    pre_margin=$(( $pre_margin*60 ))
    post_margin=$(( $post_margin*60 ))
}

#
# $1 - fifth arg
#
setDuration() {
    if [ "$1" = "until" ]
    then
        end_time=`c24hr $end_time`
        duration=`getPeriod $start_time $end_time`
    fi
    if [ "$1" = "for" ]
    then
        duration=`getDuration $duration`
    fi
}

#
# $1 - channel name
# $2 - path to channels.conf file
#
isValidChannel() {
    if [ "" =  "`cat $2 | grep -o ^"$1":`" ]
    then
        echo 'false'
    else
        echo 'true'
    fi
}
#
# $1 - now (in unix time seconds)
# $2 - start time (24hr)
# $3 - duration (s)
# $4 - pre margin (s)
# $5 - post margin (s)
#
getWaitForStart() {
    local starts_in
    local ends_in

    starts_in=`getSecondsFromTo $1 $2 $(( $4-2*$4 ))`
    ends_in=`getSecondsFromTo $1 $2 $(( $3+$5 ))`

    if [ $starts_in -gt 0 ]
    then
        echo $starts_in
        return	
    fi
    if [ $starts_in -lt 0 ] && [ $ends_in -gt 0 ] 
    then
    	echo 0
        return
    fi
    
    echo $(( 24*60*60 + $starts_in ))
}
#
# $1 - now (in unix time seconds)
# $2 - start time (24hr)
# $3 - duration (s)
# $4 - pre margin (s)
# $5 - post margin (s)
#
getWaitForEnd() {
    local starts_in
    local ends_in

    starts_in=`getSecondsFromTo $1 $2 $(( $4-2*$4 ))`
    ends_in=`getSecondsFromTo $1 $2 $(( $3+$5 ))`

    if [ $starts_in -lt 0 ] && [ $ends_in -gt 0 ] 
    then
    	echo $ends_in
    else 
        echo $(( $3 + $4 + $5 ))
    fi
}
debugging() {
    echo '${now}: '${now}
    echo '${start_time}: '${start_time}
    echo '${duration}: '${duration}
    echo '${pre_margin}: '${pre_margin}
    echo '${post_margin}: '${post_margin}
    echo '${channel}: '${channel}
    echo '${pvr_scratch_dir}${name}: '${pvr_scratch_dir}${name}
}
